@@ -44,3 +44,23 @@ def test_monochrome():
 
 def test_multi():
     assert len(imread_multi('imread/tests/data/stack.tiff')) == 2
+
+@with_setup(teardown=_remove_file)
+def test_read_back_with_metadata():
+    simple = np.arange(16*16).reshape((16,16))
+    simple = simple.astype(np.uint8)
+    meta = b'123qwe'
+    imsave(_filename, simple, metadata=meta)
+    back,meta_read = imread(_filename, return_metadata=True)
+    assert np.all(simple == back)
+    assert meta == meta_read
+
+
+@with_setup(teardown=_remove_file)
+def test_read_back_colour():
+    im = np.arange(256).astype(np.uint8).reshape((32,-1))
+    im = np.dstack([im, im*0, 255-im])
+    imsave(_filename, im)
+    im2 = imread(_filename)
+    assert im.shape == im2.shape
+    assert np.all(im == im2)
